import React, { useEffect, useState } from "react";
import { createRoot } from "react-dom/client";

const Options = () => {
  const [cookieA, setCookieA] = useState<string>("");
  const [cookieB, setCookieB] = useState<string>("");
  const [status, setStatus] = useState<string>("");
  const [grabbedCookies, setGrabbedCookies] = useState<{
    a?: string;
    b?: string;
  }>({ a: undefined, b: undefined });

  const fetchCookies = () => {
    console.log('fetching cookies')
    chrome.cookies.getAllCookieStores().then((stores) => {
      stores.forEach((store) => {
        chrome.cookies.getAll({ storeId: store.id }, (cookies) => {
          cookies.forEach((cookie) => {
            if (cookie.name === "a") {
              setCookieA(cookie.value);
              setGrabbedCookies({ ...grabbedCookies, a: cookie.value });
            }
            if (cookie.name === "b") {
              setCookieB(cookie.value);
              setGrabbedCookies({ ...grabbedCookies, b: cookie.value });
            }
          });
        });
      });
    });
  };



  const saveCookies = () => {
    // Saves options to chrome.storage.sync.
    chrome.storage.sync.set(
      {
        FAEX_a: cookieA,
        FAEX_b: cookieB,
      },
      () => {
        // Update status to let user know options were saved.
        setStatus("Options saved.");
        const id = setTimeout(() => {
          setStatus("");
        }, 1000);
        return () => clearTimeout(id);
      }
    );
  };

  return (
    <>
      <div className="p-20 w-[95%] max-w-3xl m-auto">
        <div className="logo text-center">
          <ruby className="text-xl">
            FurAffinity Exporter <rt className="text-2xl">FAEX</rt>
          </ruby>
        </div>
        <div id="settings" className="mt-3 bg-gray-100 p-5 rounded">
          <h1 className="text-xl">Extension Settings</h1>
          <p>
            To use the Extension, you need to provide it with your FurAffinity
            Cookies.
          </p>
          <p>
            <a className="text-blue-700" href="http://">
              Click here
            </a>{" "}
            to find out how they're used
          </p>
          <br />
          <p>
            Follow{" "}
            <a className="text-blue-700" href="http://">
              this guide
            </a>
            , if you want to get them manually.
          </p>
          <p>
            You can also click on the <kbd className="p-1 bg-gray-300">Fetch Cookies</kbd> Button below to
            fill them automatically.
          </p>
          <br />
          <p>Once they're in the Fields, press the <kbd className="p-1 bg-gray-300">Save Cookies</kbd> Button to save them for the future.</p>
          <hr className="mt-3 mb-3 h-[3px] m-0 w-[100%] border-hidden bg-gray-200" />
          <div id="inputs" className="flex flex-col gap-4">
            <div className="field">
              <label className="text-md font-semibold" htmlFor="cookie_A">Cookie A</label>
              <input
              className="p-3 bg-gray-300 text-gray-950 placeholder-gray-600 rounded border-2 border-gray-300  w-[100%] box-border"
                type="text"
                name="cookieA"
                id="cookie_A"
                placeholder="Put your 'a' Cookie here."
              />
            </div>
            <div className="field">
              <label className="text-md font-semibold" htmlFor="cookie_B">Cookie B</label>
              <input
              className="p-3 bg-gray-300 text-gray-950 placeholder-gray-600 rounded border-2 border-gray-300  w-[100%] box-border"
                type="text"
                name="cookieB"
                id="cookie_B"
                placeholder="Put your 'b' Cookie here."
              />
            </div>
          </div>
          <div id="actions" className="mt-4">
            <button className="text-gray-50 bg-gray-800 p-2 rounded box-border mr-1" onSubmit={saveCookies}>
              Save Cookies
            </button>
            <button className="text-gray-50 bg-gray-800 p-2 rounded box-border mr-1" onSubmit={fetchCookies}>
              Fetch Cookies
            </button>
          </div>
        </div>
      </div>
    </>
  );
};

const root = createRoot(document.getElementById("root")!);

root.render(
  <React.StrictMode>
    <Options />
  </React.StrictMode>
);
